@@ -2,7 +2,7 @@
  * @file gnome-cmd-file-popmenu.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2017 Uwe Scholz\n
+ * @copyright (C) 2013-2018 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-main-win.h"
 #include "plugin_manager.h"
-#include "gnome-cmd-python-plugin.h"
 #include "gnome-cmd-user-actions.h"
 #include "utils.h"
 #include "cap.h"
@@ -295,14 +294,6 @@ static void on_execute (GtkMenuItem *menu_item, GList *files)
 }
 
 
-static void on_execute_py_plugin (GtkMenuItem *menu_item, PythonPluginData *data)
-{
-#ifdef HAVE_PYTHON
-    gnome_cmd_python_plugin_execute(data, main_win);
-#endif
-}
-
-
 static void on_execute_script (GtkMenuItem *menu_item, ScriptData *data)
 {
     GdkModifierType mask;
@@ -310,6 +301,9 @@ static void on_execute_script (GtkMenuItem *menu_item, ScriptData *data)
     gdk_window_get_pointer (NULL, NULL, NULL, &mask);
 
     GList *files = data->files;
+    
+    string quotationMarks = data->term ? "\\\"" : "\"";
+    
     if (state_is_shift (mask))
     {
         // Run script per file
@@ -317,7 +311,7 @@ static void on_execute_script (GtkMenuItem *menu_item, ScriptData *data)
         {
             GnomeCmdFile *f = (GnomeCmdFile *) files->data;
             string command (data->name);
-            command.append (" ").append (f->get_name ());
+            command.append (" ").append (quotationMarks).append (f->get_name ()).append (quotationMarks);
 
             run_command_indir (command.c_str (), f->get_dirname (), data->term);
         }
@@ -330,7 +324,7 @@ static void on_execute_script (GtkMenuItem *menu_item, ScriptData *data)
         for (; files; files = files->next)
         {
             GnomeCmdFile *f = (GnomeCmdFile *) files->data;
-            command.append(f->get_name ()).append(" ");
+            command.append (quotationMarks).append(f->get_name ()).append (quotationMarks).append (" ");
         }
 
         run_command_indir (command.c_str (), ((GnomeCmdFile *) data->files->data)->get_dirname (), data->term);
@@ -740,71 +734,37 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     if (match_count > 0)
         gnome_app_fill_menu (GTK_MENU_SHELL (menu), sep_uiinfo, NULL, FALSE, pos++);
 
-    GList *py_plugins = NULL;
-#ifdef HAVE_PYTHON
-    py_plugins = gnome_cmd_python_plugin_get_list();
-#endif
-    guint n = g_list_length (py_plugins);
-
-    if (n)
-    {
-        GnomeUIInfo *py_uiinfo = g_new0 (GnomeUIInfo, n+1);
-        GnomeUIInfo *tmp = py_uiinfo;
-
-        for (; py_plugins; py_plugins = py_plugins->next, ++tmp)
-        {
-            PythonPluginData *data = (PythonPluginData *) py_plugins->data;
-
-            if (data)
-            {
-                tmp->type = GNOME_APP_UI_ITEM;
-                tmp->label = _(data->name);
-                tmp->moreinfo = (gpointer) on_execute_py_plugin;
-                tmp->user_data = data;
-                tmp->pixmap_type = GNOME_APP_PIXMAP_NONE; // GNOME_APP_PIXMAP_FILENAME;
-                // tmp->pixmap_info = "pixmaps/python-plugin.svg";
-            }
-        }
-
-        tmp->type = GNOME_APP_UI_ENDOFINFO;
-
-        gnome_app_fill_menu (GTK_MENU_SHELL (menu), py_uiinfo, NULL, FALSE, pos);
-        pos += n;
-        gnome_app_fill_menu (GTK_MENU_SHELL (menu), sep_uiinfo, NULL, FALSE, pos++);
-
-        g_free (py_uiinfo);
-    }
-	
     // Script actions
     gchar *user_dir = g_build_filename (g_get_home_dir (), "." PACKAGE "/scripts", NULL);
     DIR *dp = opendir (user_dir);
-    GList *slist = NULL;
+    GList *script_list = NULL;
     if (dp != NULL)
     {
-        struct dirent *ep;
-        while ((ep = readdir (dp)))
+        struct dirent *directory_entry;
+        while ((directory_entry = readdir (dp)))
         {
             struct stat buf;
-            string s (user_dir);
-            s.append ("/").append (ep->d_name);
-            if (stat (s.c_str(), &buf) == 0)
+            string script_path (user_dir);
+            script_path.append ("/").append (directory_entry->d_name);
+            if (stat (script_path.c_str(), &buf) == 0)
             {
                 if (buf.st_mode & S_IFREG)
                 {
-                    slist = g_list_append (slist, g_strdup(ep->d_name));
+                    DEBUG('p', "Adding \'%s\' to the list of scripts.\n", script_path.c_str());
+                    script_list = g_list_append (script_list, g_strdup(directory_entry->d_name));
                 }
             }
         }
         closedir (dp);
     }
 
-    n = g_list_length(slist);
+    guint n = g_list_length(script_list);
     if (n)
     {
         GnomeUIInfo *py_uiinfo = g_new0 (GnomeUIInfo, n+1);
         GnomeUIInfo *tmp = py_uiinfo;
 
-        for (GList *l = slist; l; l = l->next)
+        for (GList *l = script_list; l; l = l->next)
         {
             ScriptData *data = g_new0 (ScriptData, 1);
             data->files = files;
@@ -851,7 +811,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
         g_free (py_uiinfo);
     }
     g_free (user_dir);
-    g_list_free (slist);
+    g_list_free (script_list);
 
     gnome_app_fill_menu (GTK_MENU_SHELL (menu), other_uiinfo, NULL, FALSE, pos++);
 
