@@ -17,6 +17,7 @@
  */
 
 #include <glib.h>
+#include "gnome-cmd-mime-config.h"
 
 /** 
  * This function adds a path stored in MIMETOP_DIR to the environment
@@ -31,7 +32,7 @@ void gnome_cmd_mime_config(void)
 		g_strdup_printf(
 				"%s:%s",
 				MIMETOP_DIR,
-				(old_xdg_data_dirs ? old_xdg_data_dirs : "/usr/share/:/usr/share/local/")
+				(old_xdg_data_dirs ? old_xdg_data_dirs : "/usr/share/:/usr/local/share/")
 			);
 	g_setenv("XDG_DATA_DIRS", new_xdg_data_dirs, 1);
 	g_free(new_xdg_data_dirs);
