@@ -2,7 +2,7 @@
  * @file gnome-cmd-user-actions.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2017 Uwe Scholz\n
+ * @copyright (C) 2013-2018 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-main-win.h"
-#include "gnome-cmd-python-plugin.h"
 #include "gnome-cmd-user-actions.h"
 #include "gnome-cmd-dir-indicator.h"
 #include "gnome-cmd-style.h"
@@ -251,7 +250,6 @@ static UserActionData user_actions_data[] = {
                                              {options_edit, "options.edit", N_("Options")},
                                              {options_edit_shortcuts, "options.shortcuts", N_("Keyboard shortcuts")},
                                              {plugins_configure, "plugins.configure", N_("Configure plugins")},
-                                             {plugins_execute_python, "plugins.execute_python", N_("Execute Python plugin")},
                                              {view_back, "view.back", N_("Back one directory")},
                                              {view_close_tab, "view.close_tab", N_("Close the current tab")},
                                              {view_close_all_tabs, "view.close_all_tabs", N_("Close all tabs")},
@@ -387,13 +385,6 @@ void GnomeCmdUserActions::init()
     if (!registered("options.edit"))
         register_action(GDK_CONTROL_MASK, GDK_O, "options.edit");
 
-    if (!registered("plugins.execute_python"))
-    {
-        register_action(GDK_CONTROL_MASK, GDK_5, "plugins.execute_python", "md5sum");
-        register_action(GDK_CONTROL_MASK, GDK_KP_5, "plugins.execute_python", "md5sum");
-        register_action(GDK_CONTROL_MASK, GDK_KP_Begin, "plugins.execute_python", "md5sum");
-    }
-
     if (!registered("dir_history"))
     {
         register_action(GDK_MOD1_MASK, GDK_Down, "view.dir_history");
@@ -1958,28 +1949,6 @@ void plugins_configure (GtkMenuItem *menuitem, gpointer not_used)
 }
 
 
-void plugins_execute_python (GtkMenuItem *menuitem, gpointer python_script)
-{
-    if (!python_script)
-        return;
-
-#ifdef HAVE_PYTHON
-    for (GList *py_plugins = gnome_cmd_python_plugin_get_list(); py_plugins; py_plugins = py_plugins->next)
-    {
-        PythonPluginData *py_plugin = (PythonPluginData *) py_plugins->data;
-
-        if (!g_ascii_strcasecmp (py_plugin->name, (gchar *) python_script))
-        {
-            gnome_cmd_python_plugin_execute (py_plugin, main_win);
-            return;
-        }
-    }
-#else
-    g_warning ("Python plugins not supported");
-#endif
-}
-
-
 /************** Help Menu **************/
 
 void help_help (GtkMenuItem *menuitem, gpointer not_used)
@@ -2032,7 +2001,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
                                      "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak\n"
-                                     "Copyright \xc2\xa9 2013-2017 Uwe Scholz";
+                                     "Copyright \xc2\xa9 2013-2018 Uwe Scholz";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
